import { jsxs, jsx } from 'react/jsx-runtime';
import { useState, useRef, useEffect } from 'react';

const styles = {
    pad: {
        display: 'inline-block',
        overflowWrap: 'break-word'
    },
    pre: {
        margin: '0px',
        whiteSpace: 'pre-wrap'
    },
    input: {
        resize: 'none',
        display: 'block',
        color: 'var(--editor-text-color)',
        backgroundColor: 'var(--editor-background-color)'
    },
    root: {
        position: 'relative'
    },
    codeControl: {
        backgroundColor: 'var(--editor-control-color)'
    }
};
const inputStyle = {
    ...styles.pad,
    ...styles.input
};
const codeStyle = {
    ...styles.pad
};
const preStyle = {
    ...styles.pre
};
function Editor({ title , value ='' , onChange =()=>{} , highlight =()=>'' , ...props }) {
    const [text, setText] = useState(value);
    const [output, setOutput] = useState(()=>highlight(text));
    const codeRef = useRef();
    const textareaRef = useRef();
    function update(code) {
        const highlighted = highlight(code);
        setText(code);
        setOutput(highlighted);
        onChange(code);
    }
    useEffect(()=>{
        update(value);
    }, [
        value
    ]);
    function onInput(event) {
        const code = event.target.value || '';
        update(code);
    }
    return /*#__PURE__*/ jsxs("div", {
        ...props,
        children: [
            /*#__PURE__*/ jsxs("div", {
                className: "editor-header",
                children: [
                    /*#__PURE__*/ jsxs("div", {
                        className: "editor-controls",
                        children: [
                            /*#__PURE__*/ jsx("span", {
                                className: "editor-controls__control",
                                style: styles.codeControl
                            }),
                            /*#__PURE__*/ jsx("span", {
                                className: "editor-controls__control",
                                style: styles.codeControl
                            }),
                            /*#__PURE__*/ jsx("span", {
                                className: "editor-controls__control",
                                style: styles.codeControl
                            })
                        ]
                    }),
                    /*#__PURE__*/ jsx("div", {
                        className: "editor-title",
                        children: title || ''
                    })
                ]
            }),
            /*#__PURE__*/ jsxs("div", {
                style: styles.root,
                children: [
                    /*#__PURE__*/ jsx("pre", {
                        style: preStyle,
                        children: /*#__PURE__*/ jsx("code", {
                            style: codeStyle,
                            ref: codeRef,
                            dangerouslySetInnerHTML: {
                                __html: output
                            }
                        })
                    }),
                    /*#__PURE__*/ jsx("textarea", {
                        ref: textareaRef,
                        style: inputStyle,
                        value: text,
                        onChange: onInput
                    })
                ]
            })
        ]
    });
}

export { Editor };
